==> fragment-shader-4.0.1.tgz: package/classes/SandBox.ts <==
import { Shader, Editor } from './';
import { DEFAULT_FRAGMENT_SHADER } from './../constants/glsl-defaults';
import { type Uniform } from '../types/uniforms';
import { type ShaderConfig } from '../types/shader';
import { EditorConfig } from '../types/editor';
import { getParentFromConfig } from '../util/dom';

export default class Sandbox {
  private shader: string;
  private uniforms: Uniform[];
  private parent: HTMLElement | null;
  private animate: boolean;
  private instances: {
    shader: Shader;
    editor: Editor;
  };

  constructor(config: ShaderConfig = {}) {
    this.parent = getParentFromConfig(config);

    const { shader, uniforms, animate } = {
      shader: DEFAULT_FRAGMENT_SHADER,
      uniforms: [],
      animate: true,
      ...(config || {}),
    };

    this.shader = shader;
    this.uniforms = uniforms;
    this.animate = animate;

    const shaderConfig: ShaderConfig = {
      fragmentShader: this.shader,
      parent: this.parent,
      dpr: Math.max(1, window.devicePixelRatio / 2),
      uniforms: this.uniforms,
      animate: this.animate,
      shaderpad: config.shaderpad,
    };

    const editorConfig: EditorConfig = {
      doc: this.shader,
      uniforms: this.uniforms,
      onUpdate: this.onUpdate.bind(this) as any,
    };

    this.instances = {
      shader: new Shader(shaderConfig),
      editor: new Editor(editorConfig),
    };
  }

  onUpdate(fragmentShader: string): void {
    this.instances.shader.rebuild({ fragmentShader, uniforms: this.uniforms });
  }

  set uniform(val: Uniform) {
    this.instances.shader.uniform = val;
  }
}

==> fragment-shader-4.1.0.tgz: package/classes/SandBox.ts <==
import { Shader, Editor } from './';
import { DEFAULT_FRAGMENT_SHADER } from './../constants/glsl-defaults';
import { type UniformTuple, type ShaderConfig, type EditorConfig } from '../types';
import { getParentFromConfig } from '../util/dom';

export default class Sandbox {
  private shader: string;
  private uniforms: UniformTuple[];
  private parent: HTMLElement | null;
  private animate: boolean;
  private instances: {
    shader: Shader;
    editor: Editor;
  };

  constructor(config: ShaderConfig = {}) {
    this.parent = getParentFromConfig(config);

    const { shader, uniforms, animate } = {
      shader: DEFAULT_FRAGMENT_SHADER,
      uniforms: [],
      animate: true,
      ...(config || {}),
    };

    this.shader = shader;
    this.uniforms = uniforms;
    this.animate = animate;

    const shaderConfig: ShaderConfig = {
      fragmentShader: this.shader,
      parent: this.parent,
      dpr: Math.max(1, window.devicePixelRatio / 2),
      uniforms: this.uniforms,
      animate: this.animate,
      shaderpad: config.shaderpad,
    };

    const editorConfig: EditorConfig = {
      doc: this.shader,
      uniforms: this.uniforms,
      onUpdate: this.onUpdate.bind(this) as any,
    };

    this.instances = {
      shader: new Shader(shaderConfig),
      editor: new Editor(editorConfig),
    };
  }

  onUpdate(fragmentShader: string): void {
    this.instances.shader.rebuild({ fragmentShader, uniforms: this.uniforms });
  }

  set uniform(val: UniformTuple) {
    this.instances.shader.uniform = val;
  }
}
